@@ -41,6 +41,7 @@ from .types.translation_config import (
     BigQueryDialect,
     Dialect,
     HiveQLDialect,
+    MySQLDialect,
     NameMappingKey,
     NameMappingValue,
     NetezzaDialect,
@@ -79,6 +80,7 @@ __all__ = (
     "MigrationSubtask",
     "MigrationTask",
     "MigrationWorkflow",
+    "MySQLDialect",
     "NameMappingKey",
     "NameMappingValue",
     "NetezzaDialect",
