@@ -16,31 +16,35 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.bigquery_migration_v2alpha.services.migration_service import pagers
-from google.cloud.bigquery_migration_v2alpha.types import migration_entities
-from google.cloud.bigquery_migration_v2alpha.types import migration_error_details
-from google.cloud.bigquery_migration_v2alpha.types import migration_metrics
-from google.cloud.bigquery_migration_v2alpha.types import migration_service
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import error_details_pb2  # type: ignore
-from .transports.base import MigrationServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import MigrationServiceGrpcAsyncIOTransport
+
+from google.cloud.bigquery_migration_v2alpha.services.migration_service import pagers
+from google.cloud.bigquery_migration_v2alpha.types import (
+    migration_entities,
+    migration_error_details,
+    migration_metrics,
+    migration_service,
+)
+
 from .client import MigrationServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, MigrationServiceTransport
+from .transports.grpc_asyncio import MigrationServiceGrpcAsyncIOTransport
 
 
 class MigrationServiceAsyncClient:
@@ -231,9 +235,9 @@ class MigrationServiceAsyncClient:
 
             from google.cloud import bigquery_migration_v2alpha
 
-            def sample_create_migration_workflow():
+            async def sample_create_migration_workflow():
                 # Create a client
-                client = bigquery_migration_v2alpha.MigrationServiceClient()
+                client = bigquery_migration_v2alpha.MigrationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_migration_v2alpha.CreateMigrationWorkflowRequest(
@@ -241,7 +245,7 @@ class MigrationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_migration_workflow(request=request)
+                response = await client.create_migration_workflow(request=request)
 
                 # Handle the response
                 print(response)
@@ -337,9 +341,9 @@ class MigrationServiceAsyncClient:
 
             from google.cloud import bigquery_migration_v2alpha
 
-            def sample_get_migration_workflow():
+            async def sample_get_migration_workflow():
                 # Create a client
-                client = bigquery_migration_v2alpha.MigrationServiceClient()
+                client = bigquery_migration_v2alpha.MigrationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_migration_v2alpha.GetMigrationWorkflowRequest(
@@ -347,7 +351,7 @@ class MigrationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_migration_workflow(request=request)
+                response = await client.get_migration_workflow(request=request)
 
                 # Handle the response
                 print(response)
@@ -443,9 +447,9 @@ class MigrationServiceAsyncClient:
 
             from google.cloud import bigquery_migration_v2alpha
 
-            def sample_list_migration_workflows():
+            async def sample_list_migration_workflows():
                 # Create a client
-                client = bigquery_migration_v2alpha.MigrationServiceClient()
+                client = bigquery_migration_v2alpha.MigrationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_migration_v2alpha.ListMigrationWorkflowsRequest(
@@ -456,7 +460,7 @@ class MigrationServiceAsyncClient:
                 page_result = client.list_migration_workflows(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -560,9 +564,9 @@ class MigrationServiceAsyncClient:
 
             from google.cloud import bigquery_migration_v2alpha
 
-            def sample_delete_migration_workflow():
+            async def sample_delete_migration_workflow():
                 # Create a client
-                client = bigquery_migration_v2alpha.MigrationServiceClient()
+                client = bigquery_migration_v2alpha.MigrationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_migration_v2alpha.DeleteMigrationWorkflowRequest(
@@ -570,7 +574,7 @@ class MigrationServiceAsyncClient:
                 )
 
                 # Make the request
-                client.delete_migration_workflow(request=request)
+                await client.delete_migration_workflow(request=request)
 
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.DeleteMigrationWorkflowRequest, dict]):
@@ -644,14 +648,13 @@ class MigrationServiceAsyncClient:
         signaled if the state is anything other than DRAFT or
         RUNNING.
 
-
         .. code-block:: python
 
             from google.cloud import bigquery_migration_v2alpha
 
-            def sample_start_migration_workflow():
+            async def sample_start_migration_workflow():
                 # Create a client
-                client = bigquery_migration_v2alpha.MigrationServiceClient()
+                client = bigquery_migration_v2alpha.MigrationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_migration_v2alpha.StartMigrationWorkflowRequest(
@@ -659,7 +662,7 @@ class MigrationServiceAsyncClient:
                 )
 
                 # Make the request
-                client.start_migration_workflow(request=request)
+                await client.start_migration_workflow(request=request)
 
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.StartMigrationWorkflowRequest, dict]):
@@ -742,9 +745,9 @@ class MigrationServiceAsyncClient:
 
             from google.cloud import bigquery_migration_v2alpha
 
-            def sample_get_migration_subtask():
+            async def sample_get_migration_subtask():
                 # Create a client
-                client = bigquery_migration_v2alpha.MigrationServiceClient()
+                client = bigquery_migration_v2alpha.MigrationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_migration_v2alpha.GetMigrationSubtaskRequest(
@@ -752,7 +755,7 @@ class MigrationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_migration_subtask(request=request)
+                response = await client.get_migration_subtask(request=request)
 
                 # Handle the response
                 print(response)
@@ -851,9 +854,9 @@ class MigrationServiceAsyncClient:
 
             from google.cloud import bigquery_migration_v2alpha
 
-            def sample_list_migration_subtasks():
+            async def sample_list_migration_subtasks():
                 # Create a client
-                client = bigquery_migration_v2alpha.MigrationServiceClient()
+                client = bigquery_migration_v2alpha.MigrationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_migration_v2alpha.ListMigrationSubtasksRequest(
@@ -864,7 +867,7 @@ class MigrationServiceAsyncClient:
                 page_result = client.list_migration_subtasks(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
